Documentation
¶
Index ¶
- func CreateBlob(ctx context.Context, table string, column string, size int64, ...) (int64, error)
- func Exec(ctx context.Context, query string, params map[string]interface{}, ...) error
- func ExecMulti(ctx context.Context, queries []string, params []map[string]interface{}, ...) error
- func ExecMultiTx(ctx context.Context, queries []string, params []map[string]interface{}, ...) error
- func StreamReadBlob(ctx context.Context, table string, column string, rowID int64, offset int64, ...) (int64, error)
- func WriteBlobChunk(ctx context.Context, table string, column string, rowID int64, offset int64, ...) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateBlob ¶
func CreateBlob( ctx context.Context, table string, column string, size int64, extraCols map[string]interface{}, ) (int64, error)
CreateBlob inserts a new row into the specified table/column using zeroblob(size) and any extra columns you want to set. It returns the new rowID.
func Exec ¶
func Exec(ctx context.Context, query string, params map[string]interface{}, resultFunc func(int, map[string]interface{})) error
Exec executes a single SQL statement with parameters.
func ExecMulti ¶
func ExecMulti(ctx context.Context, queries []string, params []map[string]interface{}, resultFunc func(int, map[string]interface{})) error
Exec executes multiple SQL statements provided as separate queries with their respective parameters. Each query in the `queries` slice corresponds to the parameters in the `params` slice by index.
func ExecMultiTx ¶
func ExecMultiTx(ctx context.Context, queries []string, params []map[string]interface{}, resultFunc func(int, map[string]interface{})) error
ExecTx executes multiple SQL statements within a single transaction. Each query in the `queries` slice corresponds to the parameters in the `params` slice by index.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.