Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ClosePool ¶
func ClosePool() error
ClosePool safely closes the global pool. It should be called during application shutdown.
func GetPool ¶
GetPool returns the initialized global pool. Returns an error if the pool is not initialized.
func InitPool ¶
InitPool initializes the global pool with the given directory. It should be called once during application startup.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.